/// Copyright Thomas Nagy 2007
/// License: QPL
#ifndef vadrth
#define vadrth

#include <QDialog>
#include <con.h>

class QLineEdit;
class QTextEdit;
class QTreeWidgetItem;
class vadrt : public QDialog
<%
	Q_OBJECT
	public:
		vadrt(QWidget *felvnl);
		QLineEdit *kitzjl;
		QLineEdit *jlzpnt;
		QLineEdit *irnyjl;
		QLineEdit *adelk;
		QString fldlgz;
%>;

#endif

